@@ -13,8 +13,8 @@ import django
 os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'django_simple_departments.settings')
 django.setup()
 if __name__ == '__main__':
-    from departments.views.roles import RoleViewSet
-    from departments.views.department import create_department, DepartmentViewSet
+    from departments.views.roles import RoleControl
+    from departments.views.department import create_department, DepartmentControl
     from departments.views.position import PositionViewSet
 
     # def response(func):
@@ -35,13 +35,17 @@ if __name__ == '__main__':
     #     res = create_department(post_data)
     #     return res
 
-    # obj = DepartmentViewSet(1)
+    obj = DepartmentControl(1)
+    # print(obj.root)
+
     # print(obj.list("sub", 2))
     # print(obj.list("all"))
     # print(obj.list("all", department_name="o"))
     # print(obj.create({"name": "前端o99", "parent_id": 2}))
     # print(obj.retrieve(3))
-    # print(obj.update(18, {"name": "前端99", "parent_id": 2, "charger_id": None}))
+    # print(obj.update(18, {"name": "前端91", "parent_id": None, "charger_id": None}))
+    # print(obj.update(18, {"name": "前端91", "parent_id": None, "charger_id": None}))
+    print(obj.update_root(1, {"name": "八分量"}))
     # print(obj.delete(2))
     # print(obj.move_show_order({"department_id": 4, "type": "up"}))
     # print(obj.create_department_user(5, [1, 2, 3]))
@@ -67,7 +71,7 @@ if __name__ == '__main__':
     # print(obj.change(1, [1, 2, 3]))
     # print(obj.delete_role_user(1, [1, 2, 3]))
 
-    obj = PositionViewSet(1)
+    # obj = PositionViewSet(1)
     # print(obj.create({"name": "岗位1", "desc": ""}))
     # print(obj.list())
     # print(obj.list("这是"))
@@ -75,7 +79,7 @@ if __name__ == '__main__':
     # print(obj.update(1, {"name": "这是岗位1", "desc": "岗位1的描述"}))
     # print(obj.delete(3))
     # print(obj.create_position_user(1, [5, 6, 7]))
-    print(obj.change(1, [1,]))
+    # print(obj.change(1, [1,]))
     # print(obj.position_user_list(1))
     # print(obj.delete_position_user(2, [1, 2, 3]))
 
