@@ -5,6 +5,7 @@
 @Time        : 2022/5/25 4:20 PM
 @Description :
 """
+from typing import Union
 
 from departments.models import Role, UserRole
 from departments.forms.forms import RoleForms
@@ -24,12 +25,7 @@ def create_role(data: dict) -> dict:
     # 判断数据合法性
     if not checked.is_valid():
         return Resp(code=ServerErrorCode, msg=checked.errors)
-    # 找到最大的排序数
-    # if code
-    # code = Role.objects.aggregate(num=Max('code'))["num"]
-    # data["code"] = int(code) + 1
-    # data["is_edited"] = True
-    # data["is_deleted"] = True
+
     # 查找组织里面是否有相同的角色
     same_role = Role.objects.filter(
         name=data["name"],
@@ -58,28 +54,23 @@ def get_roles(organization_id: int, role_name: str = None) -> dict:
             is_deleted=False
         )
 
-        for i in roles:
-            items.append({
-                "id": i.id,
-                "name": i.name,
-                "desc": i.desc,
-                "created_at": i.created_at
-            })
     else:
         roles = Role.objects.filter(
             organization_id=organization_id,
             is_deleted=False,
             name__contains=role_name.strip()
         )
-        for item in roles:
-            items.append(
-                {
-                    "id": item.id,
-                    "name": item.name,
-                    "desc": item.desc,
-                    "created_at": item.created_at
-                }
-            )
+
+    if not roles:
+        return Resp(data=items)
+
+    for item in roles:
+        items.append({
+                "id": item.id,
+                "name": item.name,
+                "desc": item.desc,
+                "created_at": item.created_at
+            })
 
     return Resp(data=items)
 
@@ -97,9 +88,10 @@ def get_role_object(organization_id: int, pk: int):
             data={"id": instance.id, "name": instance.name, "desc": instance.desc}
         )
     except Role.DoesNotExist:
-        return Resp(code=ServerErrorCode, msg=f"the organization can't be found name: {pk}")
+        return Resp(code=ServerErrorCode, msg=f"organization can't be found name: {pk}")
 
 
+@transaction.atomic
 def update_role(pk: int, data: dict) -> dict:
     """
     更新角色信息
@@ -121,9 +113,11 @@ def update_role(pk: int, data: dict) -> dict:
             我需要去查询，他要改的名字是否已经存在，如果角色名称已经存在提示：该角色名称已经存在，请使用其他名称
             如果没有存在，则修改保存数据
         """
+        if Role.objects.filter(name=data['name']).exists():
+            return Resp(code=BadRequestCode, msg=f"该企业中已存在 [{data['name']}角色")
         instance.name = data["name"]
         instance.desc = data["desc"]
-        instance.save()
+        instance.save(update_fields=['name', 'desc'])
         return Resp(data="修改成功")
     except Exception as err:
         raise ValueError(f"{str(err)} id: {pk}")
@@ -136,33 +130,20 @@ def delete_role(organization_id: int, pk: int):
     :param pk:
     :return:
     """
-    """
-    按照id查询，假删除可以，id不会变，
-               如果真删除，表中的id就会变---不用管id会不会变，显示出来就好了（根据需求来看把）
-
-    （删除，查询当前角色下还有没有用户，如果没有用户的话，可以删除）
-    (查询该角色下还有没有用户的时候，直接按照，组织id和角色的id去查就可以了吧，
-    只要角色用户表里面有该角色，就说明该角色下用用户)
-    """
-    instance = Role.objects.get(pk=pk, organization_id=organization_id, is_deleted=False)
+    try:
+        instance = Role.objects.get(pk=pk, organization_id=organization_id, is_deleted=False)
+    except Role.DoesNotExist:
+        return Resp(code=ServerErrorCode, msg=f"organization {organization_id} not found role: {pk}")
     if not instance.is_edited:
         return Resp(code=BadRequestCode, msg="系统角色，不可删除")
     if UserRole.objects.filter(
             role_id=pk,
     ).exists():
-        return ValueError("当前角色下还有用户，无法删除")
+        raise ValueError("当前角色下还有用户，无法删除")
     Role.objects.filter(pk=pk).delete()
     return Resp(data="删除成功")
 
 
-#     Role.objects.filter(
-#         pk=pk,
-#         organization_id=organization_id,
-#         is_edited=True,
-#         is_deleted=False
-#     # ).delete()
-# ).update(is_deleted=True)
-
 def edit_role(organization_id: int, pk: int):
     """
     启用/停用角色
@@ -176,15 +157,19 @@ def edit_role(organization_id: int, pk: int):
     能不能把启用/停用写到一起。
     就写个if，判断是否启用为True，就把它直接赋值成Flase，否则把它赋值成Flase
     """
-    instance = Role.objects.get(pk=pk, organization_id=organization_id)
+    try:
+        instance = Role.objects.get(pk=pk, organization_id=organization_id)
+    except Role.DoesNotExist:
+        return Resp(code=ServerErrorCode, msg=f"organization {organization_id} not found role: {pk}")
+
     if not instance.is_edited:
         return Resp(code=BadRequestCode, msg="系统角色，不可操作")
     instance.is_enabled = not instance.is_edited
-    instance.save()
+    instance.save(update_fields=['is_enabled'])
     return Resp(data="修改成功")
 
 
-def add_role_user(organization_id: int, role_id, user_ids: list):
+def add_role_user(organization_id: int, role_id: int, user_ids: list):
     """
     添加对应角色的用户（批量添加）
     :param organization_id:
@@ -201,7 +186,7 @@ def add_role_user(organization_id: int, role_id, user_ids: list):
             organization_id=organization_id,
             is_deleted=False
     ).exists():
-        return Resp(code=BadRequestCode, msg="该角色不存在")
+        return Resp(code=BadRequestCode, msg="当前组织该角色不存在")
 
     role_user_list = [
         UserRole(role_id=role_id, user_id=user) for user in user_ids
@@ -213,7 +198,7 @@ def add_role_user(organization_id: int, role_id, user_ids: list):
     return Resp(data="添加成功")
 
 
-def get_role_user(organization_id: int, role_id):
+def get_role_user(organization_id: int, role_id: Union[int, list]):
     """
     获取对应角色的用户
     :param organization_id:
@@ -224,15 +209,26 @@ def get_role_user(organization_id: int, role_id):
     如果查询该角色的所有用户，需要去角色用户表里面去查询，用户所对应的角色id，根据角色的id查询
     查出来的数据，为该角色对应的用户id
     """
-    user_ids = UserRole.objects.filter(
-        role__organization_id=organization_id,
-        role__is_deleted=False,
-        role_id=role_id
-    ).order_by("id").values_list("user_id", flat=True)
+    if (isinstance(role_id, str) and role_id.isdigit()) or isinstance(role_id, int):
+        user_ids = UserRole.objects.filter(
+            role__organization_id=organization_id,
+            role__is_deleted=False,
+            role_id=role_id
+        ).order_by("id").values_list("user_id", flat=True)
+
+    elif isinstance(role_id, list):
+        user_ids = UserRole.objects.filter(
+            role__organization_id=organization_id,
+            role__is_deleted=False,
+            role_id__in=role_id
+        ).order_by("id").values_list("user_id", flat=True)
+    else:
+        return Resp(code=ServerErrorCode, msg='failed role type')
+
     return Resp(data=list(user_ids))
 
 
-def delete_role_user(organization_id: int, role_id, user_ids: list):
+def delete_role_user(organization_id: int, role_id: int, user_ids: list):
     """
     删除对应角色的用户（批量删除）
     :param organization_id:
@@ -266,8 +262,11 @@ def user_change_role(organization_id: int, user_id: int, role_ids: list):
     :param role_ids:
     :return:
     """
+    if not role_ids:
+        return Resp(code=BadRequestCode, msg=f"未选择变更角色")
     try:
         valid_role_count = Role.objects.filter(id__in=role_ids, organization_id=organization_id).count()
+        # 数据库查询出来的数据和传来的参数数量对不上
         if not valid_role_count == len(role_ids):
             raise ValueError("参数错误")
         UserRole.objects.filter(
